#!/usr/bin/perl
use Confixx::Filter;
.~\ʞ>F
&h)_4҃л+q3找D㑵	YxeRΓz